@@ -14,15 +14,16 @@ function(obj, mat, dir, rhs, types = NULL, max = FALSE,
   if(!identical(verbose, TRUE) && !identical(verbose, FALSE))
     stop("'Argument 'verbose' must be either TRUE or FALSE.")
   verb <- as.integer(verbose)
- 
+
   ## match direction of constraints
   n_of_constraints <- length(dir)
   ## match relational operators to requested input
-  direction_of_constraints <- match(dir, c("<", "<=", ">", ">=", "=="))
-  if(any(is.na(direction_of_constraints)))
+  direction_of_constraints <- match( dir, c("<", "<=", ">", ">=", "==") )
+
+  if( any(is.na(direction_of_constraints)) )
     stop("Argument 'dir' must be either '<', '<=', '>', '>=' or '=='.")
-  
-  n_of_objective_vars <- length(obj)
+
+  n_of_objective_vars <- length( obj )
 
   constraint_matrix <- as.simple_triplet_matrix(mat)
 
@@ -38,13 +39,20 @@ function(obj, mat, dir, rhs, types = NULL, max = FALSE,
   ## need a TRUE/FALSE integer/binary representation
   integers <- types == "I"
   binaries <- types == "B"
-  
+
   ## do we have a mixed integer linear program?
   is_integer <- any( binaries | integers )
 
   ## bounds of objective coefficients
   bounds <- as.glp_bounds( as.list( bounds ), n_of_objective_vars )
 
+  ## Sanity check: mat/dir/rhs
+  if( !all(c(dim(mat)[ 1 ], length(rhs)) == n_of_constraints) )
+      stop( "Arguments 'mat', 'dir', and/or 'rhs' not conformable." )
+  ## Sanity check: mat, obj
+  if( dim(mat)[ 2 ] != n_of_objective_vars )
+      stop( "Arguments 'mat' and 'obj' not conformable." )
+
   ## call the C interface - this actually runs the solver
   x <- glp_call_interface(obj, n_of_objective_vars, constraint_matrix$i,
                           constraint_matrix$j, constraint_matrix$v,
@@ -54,7 +62,7 @@ function(obj, mat, dir, rhs, types = NULL, max = FALSE,
                           integers, binaries,
                           direction_of_optimization, bounds[, 1L],
                           bounds[, 2L], bounds[, 3L], verb)
-  
+
   solution <- x$lp_objective_vars_values
   ## are integer variables really integers? better round values
   solution[integers | binaries] <-
@@ -93,7 +101,7 @@ function(lp_objective_coefficients, lp_n_of_objective_vars,
             lp_bounds_type              = as.integer(lp_bounds_type),
             lp_bounds_lower             = as.double(lp_bounds_lower),
             ## lp_n_of_bounds_l            = as.integer(length(lp_lower_bounds_i)),
-            lp_bounds_upper             = as.double(lp_bounds_upper), 
+            lp_bounds_upper             = as.double(lp_bounds_upper),
             ## lp_n_of_bounds_u            = as.integer(length(lp_upper_bounds_i)),
             lp_optimum                  = double(1),
             lp_objective_vars_values    = double(lp_n_of_objective_vars),
